--
--  Copyright 2013 Anyware Services
--
--  Licensed under the Apache License, Version 2.0 (the "License");
--  you may not use this file except in compliance with the License.
--  You may obtain a copy of the License at
--
--      http://www.apache.org/licenses/LICENSE-2.0
--
--  Unless required by applicable law or agreed to in writing, software
--  distributed under the License is distributed on an "AS IS" BASIS,
--  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
--  See the License for the specific language governing permissions and
--  limitations under the License.
--

drop table if exists Cache_RA_HTTPServer;
CREATE TABLE Cache_RA_HTTPServer (
  Unique_Id VARCHAR(255) NOT NULL,
  Site VARCHAR(255) NOT NULL,
  Request_Date TIMESTAMP NOT NULL,
  Method VARCHAR(255) NOT NULL,
  Path_Hash VARCHAR(255) NOT NULL,
  Path TEXT NOT NULL,
  Query_String TEXT NOT NULL,
  Ori_Status_Code CHAR(3) NOT NULL,
  Ret_Status_Code CHAR(3) NOT NULL,
  Cache_Hit TINYINT(1) NOT NULL,
  Created_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  Processed TINYINT(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (Unique_Id)
) ENGINE=InnoDB;

drop table if exists Cache_RA_Front;
CREATE TABLE Cache_RA_Front (
  Unique_Id VARCHAR(255) NOT NULL,
  Internal_Uuid VARCHAR(255) NOT NULL,
  Site VARCHAR(255) NOT NULL,
  Ametys_Path_Hash VARCHAR(255) NOT NULL,
  Ametys_Path TEXT NOT NULL,
  Cacheable TINYINT(1) NOT NULL,
  Cache_Hit_1 TINYINT(1) NOT NULL,
  Cache_Hit_2 TINYINT(1) NOT NULL,
  Created_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  Processed TINYINT(1) NOT NULL DEFAULT 0
) ENGINE=InnoDB;

drop table if exists Cache_RA_Back;
CREATE TABLE Cache_RA_Back (
  Internal_Uuid VARCHAR(255) NOT NULL,
  Page_Id VARCHAR(255) NOT NULL,
  Page_Path_Hash VARCHAR(255) NOT NULL,
  Page_Path TEXT NOT NULL,
  Rendering_Context VARCHAR(255) NOT NULL,
  Workspace_JCR VARCHAR(255) NOT NULL,
  Cacheable TINYINT(1) NOT NULL,
  Created_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  Processed TINYINT(1) NOT NULL DEFAULT 0
) ENGINE=InnoDB;

drop table if exists Cache_RA_Back_Page_Element;
CREATE TABLE Cache_RA_Back_Page_Element (
  Internal_Uuid VARCHAR(255) NOT NULL,
  Page_Element_Id VARCHAR(255) NOT NULL,
  Page_Element_Type VARCHAR(255) NOT NULL,
  Page_Id VARCHAR(255) NOT NULL,
  Rendering_Context VARCHAR(255) NOT NULL,
  Workspace_JCR VARCHAR(255) NOT NULL,
  Cacheable TINYINT(1) NOT NULL,
  Cache_Hit TINYINT(1) NOT NULL,
  Created_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  Processed TINYINT(1) NOT NULL DEFAULT 0
) ENGINE=InnoDB;

drop table if exists Cache_Stats_Front;
CREATE TABLE Cache_Stats_Front (
  Server_Site VARCHAR(255) NOT NULL DEFAULT '-',
  Server_Path_Hash VARCHAR(255) NOT NULL DEFAULT '-',
  Server_Path TEXT,
  Server_Hits INT NOT NULL DEFAULT 0,
  Server_Cache_Hits INT NOT NULL DEFAULT 0,
  Front_Site VARCHAR(255) NOT NULL DEFAULT '-',
  Front_Path_Hash VARCHAR(255) NOT NULL DEFAULT '-',
  Front_Path TEXT,
  Front_Cacheable TINYINT(1) NOT NULL DEFAULT 0,
  Front_Hits INT NOT NULL DEFAULT 0,
  Front_Cache_Hits_1 INT NOT NULL DEFAULT 0,
  Front_Cache_Hits_2 INT NOT NULL DEFAULT 0,
  Created_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  Updated_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  UNIQUE KEY (Server_Site, Server_Path_Hash, Front_Site, Front_Path_Hash)
) ENGINE=InnoDB;

drop table if exists Cache_Stats_Back;
CREATE TABLE Cache_Stats_Back (
  Page_Id VARCHAR(255) NOT NULL,
  Page_Path_Hash VARCHAR(255) NOT NULL,
  Page_Path TEXT NOT NULL,
  Rendering_Context VARCHAR(255) NOT NULL,
  Workspace_JCR VARCHAR(255) NOT NULL,
  Cacheable TINYINT(1) NOT NULL,
  Hits INT NOT NULL,
  Created_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  Updated_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  PRIMARY KEY (Page_Id, Rendering_Context, Workspace_JCR)
) ENGINE=InnoDB;

drop table if exists Cache_Stats_Back_Page_Element;
CREATE TABLE Cache_Stats_Back_Page_Element (
  Page_Element_Id VARCHAR(255) NOT NULL,
  Page_Id VARCHAR(255) NOT NULL,
  Rendering_Context VARCHAR(255) NOT NULL,
  Workspace_JCR VARCHAR(255) NOT NULL,
  Cacheable TINYINT(1) NOT NULL,
  Hits INT NOT NULL,
  Cache_Hits INT NOT NULL,
  Created_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  Updated_At TIMESTAMP NOT NULL DEFAULT 0, -- The DEFAULT clause prevents weird auto update (See Mysql doc)
  PRIMARY KEY (Page_Element_Id, Page_Id, Rendering_Context, Workspace_JCR)
) ENGINE=InnoDB;
